Module: Raix
- Defined in:
- lib/raix.rb,
lib/raix/mcp.rb,
lib/raix/version.rb,
lib/raix/mcp/tool.rb,
lib/raix/predicate.rb,
lib/raix/configuration.rb,
lib/raix/mcp/sse_client.rb,
lib/raix/chat_completion.rb,
lib/raix/response_format.rb,
lib/raix/mcp/stdio_client.rb,
lib/raix/function_dispatch.rb,
lib/raix/completion_context.rb,
lib/raix/transcript_adapter.rb,
lib/raix/prompt_declarations.rb,
lib/raix/function_tool_adapter.rb,
lib/raix/message_adapters/base.rb
Overview
This module provides a way to chain prompts and handle user responses in a serialized manner, with support for functions if the FunctionDispatch module is also included.
Defined Under Namespace
Modules: ChatCompletion, FunctionDispatch, MCP, MessageAdapters, Predicate, PromptDeclarations Classes: CompletionContext, Configuration, FunctionToolAdapter, ResponseFormat, TranscriptAdapter, UndeclaredToolError
Constant Summary collapse
- VERSION =
"2.0.3"
Class Attribute Summary collapse
-
.configuration ⇒ Object
Returns the current configuration instance.
Class Method Summary collapse
-
.configure {|configuration| ... } ⇒ Object
Configures the Raix gem using a block.
Class Attribute Details
.configuration ⇒ Object
Returns the current configuration instance.
13 14 15 |
# File 'lib/raix.rb', line 13 def self.configuration @configuration ||= Configuration.new end |
Class Method Details
.configure {|configuration| ... } ⇒ Object
Configures the Raix gem using a block.
18 19 20 |
# File 'lib/raix.rb', line 18 def self.configure yield(configuration) end |